@@ -16,42 +16,32 @@ Usage::
     list_repository_associations_paginator: ListRepositoryAssociationsPaginator = client.get_paginator("list_repository_associations")
     ```
 """
-import sys
 from typing import Iterator, List
 
 from botocore.paginate import Paginator as Boto3Paginator
 
+from mypy_boto3_codeguru_reviewer.literals import ProviderType, RepositoryAssociationState
 from mypy_boto3_codeguru_reviewer.type_defs import (
     ListRepositoryAssociationsResponseTypeDef,
     PaginatorConfigTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("ListRepositoryAssociationsPaginator",)
 
 
 class ListRepositoryAssociationsPaginator(Boto3Paginator):
     """
-    [Paginator.ListRepositoryAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations)
+    [Paginator.ListRepositoryAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations)
     """
 
     def paginate(
         self,
-        ProviderTypes: List[
-            Literal["CodeCommit", "GitHub", "Bitbucket", "GitHubEnterpriseServer"]
-        ] = None,
-        States: List[
-            Literal["Associated", "Associating", "Failed", "Disassociating", "Disassociated"]
-        ] = None,
+        ProviderTypes: List[ProviderType] = None,
+        States: List[RepositoryAssociationState] = None,
         Names: List[str] = None,
         Owners: List[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListRepositoryAssociationsResponseTypeDef]:
         """
-        [ListRepositoryAssociations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations.paginate)
+        [ListRepositoryAssociations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations.paginate)
         """
