@@ -13,10 +13,15 @@ import sys
 from datetime import datetime
 from typing import Dict, List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_codeguru_reviewer.literals import (
+    EncryptionOption,
+    JobState,
+    ProviderType,
+    Reaction,
+    RepositoryAssociationState,
+    TypeType,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -65,11 +70,11 @@ CodeReviewSummaryTypeDef = TypedDict(
         "CodeReviewArn": str,
         "RepositoryName": str,
         "Owner": str,
-        "ProviderType": Literal["CodeCommit", "GitHub", "Bitbucket", "GitHubEnterpriseServer"],
-        "State": Literal["Completed", "Pending", "Failed", "Deleting"],
+        "ProviderType": ProviderType,
+        "State": JobState,
         "CreatedTimeStamp": datetime,
         "LastUpdatedTimeStamp": datetime,
-        "Type": Literal["PullRequest", "RepositoryAnalysis"],
+        "Type": TypeType,
         "PullRequestId": str,
         "MetricsSummary": "MetricsSummaryTypeDef",
     },
@@ -83,12 +88,12 @@ CodeReviewTypeDef = TypedDict(
         "CodeReviewArn": str,
         "RepositoryName": str,
         "Owner": str,
-        "ProviderType": Literal["CodeCommit", "GitHub", "Bitbucket", "GitHubEnterpriseServer"],
-        "State": Literal["Completed", "Pending", "Failed", "Deleting"],
+        "ProviderType": ProviderType,
+        "State": JobState,
         "StateReason": str,
         "CreatedTimeStamp": datetime,
         "LastUpdatedTimeStamp": datetime,
-        "Type": Literal["PullRequest", "RepositoryAnalysis"],
+        "Type": TypeType,
         "PullRequestId": str,
         "SourceCodeType": "SourceCodeTypeTypeDef",
         "AssociationArn": str,
@@ -102,9 +107,7 @@ CommitDiffSourceCodeTypeTypeDef = TypedDict(
 )
 
 KMSKeyDetailsTypeDef = TypedDict(
-    "KMSKeyDetailsTypeDef",
-    {"KMSKeyId": str, "EncryptionOption": Literal["AWS_OWNED_CMK", "CUSTOMER_MANAGED_CMK"]},
-    total=False,
+    "KMSKeyDetailsTypeDef", {"KMSKeyId": str, "EncryptionOption": EncryptionOption}, total=False
 )
 
 MetricsSummaryTypeDef = TypedDict(
@@ -117,7 +120,7 @@ MetricsTypeDef = TypedDict(
 
 RecommendationFeedbackSummaryTypeDef = TypedDict(
     "RecommendationFeedbackSummaryTypeDef",
-    {"RecommendationId": str, "Reactions": List[Literal["ThumbsUp", "ThumbsDown"]], "UserId": str},
+    {"RecommendationId": str, "Reactions": List[Reaction], "UserId": str},
     total=False,
 )
 
@@ -126,7 +129,7 @@ RecommendationFeedbackTypeDef = TypedDict(
     {
         "CodeReviewArn": str,
         "RecommendationId": str,
-        "Reactions": List[Literal["ThumbsUp", "ThumbsDown"]],
+        "Reactions": List[Reaction],
         "UserId": str,
         "CreatedTimeStamp": datetime,
         "LastUpdatedTimeStamp": datetime,
@@ -159,8 +162,8 @@ RepositoryAssociationSummaryTypeDef = TypedDict(
         "AssociationId": str,
         "Name": str,
         "Owner": str,
-        "ProviderType": Literal["CodeCommit", "GitHub", "Bitbucket", "GitHubEnterpriseServer"],
-        "State": Literal["Associated", "Associating", "Failed", "Disassociating", "Disassociated"],
+        "ProviderType": ProviderType,
+        "State": RepositoryAssociationState,
     },
     total=False,
 )
@@ -173,8 +176,8 @@ RepositoryAssociationTypeDef = TypedDict(
         "ConnectionArn": str,
         "Name": str,
         "Owner": str,
-        "ProviderType": Literal["CodeCommit", "GitHub", "Bitbucket", "GitHubEnterpriseServer"],
-        "State": Literal["Associated", "Associating", "Failed", "Disassociating", "Disassociated"],
+        "ProviderType": ProviderType,
+        "State": RepositoryAssociationState,
         "StateReason": str,
         "LastUpdatedTimeStamp": datetime,
         "CreatedTimeStamp": datetime,
